#!/usr/bin/env python
fieldIDs = {
    'url': 1,
    'rights': 2,
    'series': 3,
    'volume': 4,
    'issue': 5,
    'edition': 6,
    'place': 7,
    'publisher': 8,
    'pages': 10,
    'ISBN': 11,
    'publicationTitle': 12,
    'ISSN': 13,
    'date': 14,
    'section': 15,
    'callNumber': 18,
    'archiveLocation': 19,
    'distributor': 21,
    'extra': 22,
    'journalAbbreviation': 25,
    'DOI': 26,
    'accessDate': 27,
    'seriesTitle': 28,
    'seriesText': 29,
    'seriesNumber': 30,
    'institution': 31,
    'reportType': 32,
    'code': 36,
    'session': 40,
    'legislativeBody': 41,
    'history': 42,
    'reporter': 43,
    'court': 44,
    'numberOfVolumes': 45,
    'committee': 46,
    'assignee': 48,
    'patentNumber': 50,
    'priorityNumbers': 51,
    'issueDate': 52,
    'references': 53,
    'legalStatus': 54,
    'codeNumber': 55,
    'artworkMedium': 59,
    'number': 60,
    'artworkSize': 61,
    'libraryCatalog': 62,
    'videoRecordingFormat': 63,
    'interviewMedium': 64,
    'letterType': 65,
    'manuscriptType': 66,
    'mapType': 67,
    'scale': 68,
    'thesisType': 69,
    'websiteType': 70,
    'audioRecordingFormat': 71,
    'label': 72,
    'presentationType': 74,
    'meetingName': 75,
    'studio': 76,
    'runningTime': 77,
    'network': 78,
    'postType': 79,
    'audioFileType': 80,
    'versionNumber': 81,
    'system': 82,
    'company': 83,
    'conferenceName': 84,
    'encyclopediaTitle': 85,
    'dictionaryTitle': 86,
    'language': 87,
    'programmingLanguage': 88,
    'university': 89,
    'abstractNote': 90,
    'websiteTitle': 91,
    'reportNumber': 92,
    'billNumber': 93,
    'codeVolume': 94,
    'codePages': 95,
    'dateDecided': 96,
    'reporterVolume': 97,
    'firstPage': 98,
    'documentNumber': 99,
    'dateEnacted': 100,
    'publicLawNumber': 101,
    'country': 102,
    'applicationNumber': 103,
    'forumTitle': 104,
    'episodeNumber': 105,
    'blogTitle': 107,
    'type': 108,
    'medium': 109,
    'title': 110,
    'caseName': 111,
    'nameOfAct': 112,
    'subject': 113,
    'proceedingsTitle': 114,
    'bookTitle': 115,
    'shortTitle': 116,
    'docketNumber': 117,
    'numPages': 118,
    'programTitle': 119,
    'issuingAuthority': 120,
    'filingDate': 121,
    'genre': 122,
    'archive': 123
}
