---
key: {{ citekey }}
date: {{ ts }}
author: {{ author }}
---

# {{ title }}

*Reading Notes by {{ author }} | {{ ts_day }}*

| Zotero field | Value |
| --- | --- |
| Creators | {{ creator }} |
| Citekey | {{ citekey }} |
| Type | {{ type }} |
| DOI | {% if doi %} [{{ doi }}](https://doi.org/{{ doi }}) {% else %}  {% endif %} |
| Date | {{ date }} |

*Keywords*:

---

## Short summary

## Quotes

## Further reading

---

## Detailed notes